# Welcome to Kukai

`kukai` is a command-line tool that automates creation and managemant of templates.
Rather than beeing a templating engine itselfe it wants to use templates written for projects like [`cookiecutter`](https://www.cookiecutter.io/) or [`jinja2`](https://jinja.palletsprojects.com/)


To install Kukai with `pip`:
```
pip install kukai
```
